@@ -62,12 +62,12 @@ showBinary c x y =
                                    mnodeA "degHide" "on" ()
                                 , mnode "deg" y'
                                 , mnode "e" x']
-       "\\stackrel" -> mnode "limUpp" [ mnode "e" x'
-                                       , mnode "lim" y']
-       "\\overset" -> mnode "limUpp" [ mnode "e" x'
-                                     , mnode "lim" y' ]
-       "\\underset" -> mnode "limLow" [ mnode "e" x'
-                                      , mnode "lim" y' ]
+       "\\stackrel" -> mnode "limUpp" [ mnode "e" y'
+                                       , mnode "lim" x']
+       "\\overset" -> mnode "limUpp" [ mnode "e" y'
+                                     , mnode "lim" x' ]
+       "\\underset" -> mnode "limLow" [ mnode "e" y'
+                                      , mnode "lim" x' ]
        "\\binom"    -> mnode "d" [ mnode "dPr" $
                                      mnodeA "sepChr" "," ()
                                  , mnode "e" $
@@ -171,7 +171,7 @@ showExp e =
                                   ] ]
 
    EIdentifier x    -> [str [] x]
-   EMathOperator x  -> [str [] x]
+   EMathOperator x  -> [makeText TextNormal x]
    EStretchy x      -> showExp x  -- no support for stretchy in OMML
    ESymbol _ x      -> [str [] x]
    ESpace "0.167em" -> [str [] "\x2009"]
@@ -228,7 +228,6 @@ makeNary t s y z w =
   mnode "nary" [ mnode "naryPr"
                  [ mnodeA "chr" s ()
                  , mnodeA "limLoc" t ()
-                 , mnode "grow" ()
                  , mnodeA "supHide"
                     (if y == EGrouped [] then "on" else "off") ()
                  , mnodeA "supHide"
